@@ -157,21 +157,32 @@ class KafkaConsumer(Consumer[KafkaPayload]):
         self,
         configuration: Mapping[str, Any],
     ) -> None:
+        configuration = dict(configuration)
+
+        # Feature flag to enable retrying on `Broker handle destroyed` errors
+        # which can occur if we attempt to commit during a rebalance when
+        # the consumer group coordinator changed
+        self.__retry_handle_destroyed = as_kafka_configuration_bool(
+            configuration.pop("arroyo.retry.broker.handle.destroyed", False)
+        )
+
+        retryable_errors: Tuple[int, ...] = (
+            KafkaError.REQUEST_TIMED_OUT,
+            KafkaError.NOT_COORDINATOR,
+            KafkaError._WAIT_COORD,
+            KafkaError.STALE_MEMBER_EPOCH,  # kip-848
+            KafkaError.COORDINATOR_LOAD_IN_PROGRESS,
+        )
+        if self.__retry_handle_destroyed:
+            retryable_errors += (KafkaError._DESTROY,)
+
         commit_retry_policy = BasicRetryPolicy(
             3,
             1,
             lambda e: isinstance(e, KafkaException)
-            and e.args[0].code()
-            in (
-                KafkaError.REQUEST_TIMED_OUT,
-                KafkaError.NOT_COORDINATOR,
-                KafkaError._WAIT_COORD,
-                KafkaError.STALE_MEMBER_EPOCH,  # kip-848
-                KafkaError.COORDINATOR_LOAD_IN_PROGRESS,
-            ),
+            and e.args[0].code() in retryable_errors,
         )
 
-        configuration = dict(configuration)
         self.__is_cooperative_sticky = (
             configuration.get("partition.assignment.strategy") == "cooperative-sticky"
         )
@@ -186,6 +197,13 @@ class KafkaConsumer(Consumer[KafkaPayload]):
         if self.__strict_offset_reset is None:
             self.__strict_offset_reset = True
 
+        # Feature flag to enable rdkafka auto-commit with store_offsets
+        # When enabled, offsets are stored via store_offsets() and rdkafka
+        # automatically commits them periodically
+        self.__use_auto_commit = as_kafka_configuration_bool(
+            configuration.pop("arroyo.enable.auto.commit", False)
+        )
+
         if auto_offset_reset in {"smallest", "earliest", "beginning"}:
             self.__resolve_partition_starting_offset = (
                 self.__resolve_partition_offset_earliest
@@ -201,21 +219,32 @@ class KafkaConsumer(Consumer[KafkaPayload]):
         else:
             raise ValueError("invalid value for 'auto.offset.reset' configuration")
 
-        if (
-            as_kafka_configuration_bool(configuration.get("enable.auto.commit", "true"))
-            is not False
-        ):
-            raise ValueError("invalid value for 'enable.auto.commit' configuration")
+        # When auto-commit is disabled (default), we require explicit configuration
+        # When auto-commit is enabled, we allow rdkafka to handle commits
+        if not self.__use_auto_commit:
+            if (
+                as_kafka_configuration_bool(
+                    configuration.get("enable.auto.commit", "true")
+                )
+                is not False
+            ):
+                raise ValueError("invalid value for 'enable.auto.commit' configuration")
 
-        if (
-            as_kafka_configuration_bool(
-                configuration.get("enable.auto.offset.store", "true")
-            )
-            is not False
-        ):
-            raise ValueError(
-                "invalid value for 'enable.auto.offset.store' configuration"
-            )
+            if (
+                as_kafka_configuration_bool(
+                    configuration.get("enable.auto.offset.store", "true")
+                )
+                is not False
+            ):
+                raise ValueError(
+                    "invalid value for 'enable.auto.offset.store' configuration"
+                )
+        else:
+            # In auto-commit mode, enable auto.commit and keep auto.offset.store disabled
+            # We'll use store_offsets() manually to control which offsets get committed
+            configuration["enable.auto.commit"] = True
+            configuration["enable.auto.offset.store"] = False
+            configuration["on_commit"] = self.__on_commit_callback
 
         # NOTE: Offsets are explicitly managed as part of the assignment
         # callback, so preemptively resetting offsets is not enabled when
@@ -235,6 +264,39 @@ class KafkaConsumer(Consumer[KafkaPayload]):
 
         self.__state = KafkaConsumerState.CONSUMING
 
+        self.__metrics = get_metrics()
+        self.__group_id = configuration.get("group.id")
+
+    def __on_commit_callback(
+        self,
+        error: Optional[KafkaException],
+        partitions: Sequence[ConfluentTopicPartition],
+    ) -> None:
+        if error:
+            partition_info = [f"{p.topic}:{p.partition}" for p in partitions]
+            logger.warning(
+                "Commit failed: %s. Partitions: %s",
+                error,
+                partition_info,
+            )
+            tags = {"status": "error"}
+            if self.__group_id:
+                tags["group_id"] = self.__group_id
+            self.__metrics.increment(
+                name="arroyo.consumer.commit_status",
+                value=1,
+                tags=tags,
+            )
+        else:
+            tags = {"status": "success"}
+            if self.__group_id:
+                tags["group_id"] = self.__group_id
+            self.__metrics.increment(
+                name="arroyo.consumer.commit_status",
+                value=1,
+                tags=tags,
+            )
+
     def __resolve_partition_offset_earliest(
         self, partition: ConfluentTopicPartition
     ) -> ConfluentTopicPartition:
@@ -572,7 +634,21 @@ class KafkaConsumer(Consumer[KafkaPayload]):
         # TODO: Maybe log a warning if these offsets exceed the current
         # offsets, since that's probably a side effect of an incorrect usage
         # pattern?
-        self.__staged_offsets.update(offsets)
+        if self.__use_auto_commit:
+            # When auto-commit is enabled, use store_offsets to stage offsets
+            # for rdkafka to auto-commit
+            if offsets:
+                self.__consumer.store_offsets(
+                    offsets=[
+                        ConfluentTopicPartition(
+                            partition.topic.name, partition.index, offset
+                        )
+                        for partition, offset in offsets.items()
+                    ]
+                )
+        else:
+            # Default behavior: manually track staged offsets
+            self.__staged_offsets.update(offsets)
 
     def __commit(self) -> Mapping[Partition, int]:
         if self.__state in {KafkaConsumerState.CLOSED, KafkaConsumerState.ERROR}:
@@ -620,15 +696,24 @@ class KafkaConsumer(Consumer[KafkaPayload]):
 
         return offsets
 
-    def commit_offsets(self) -> Mapping[Partition, int]:
+    def commit_offsets(self) -> Optional[Mapping[Partition, int]]:
         """
         Commit staged offsets for all partitions that this consumer is
         assigned to. The return value of this method is a mapping of
         partitions with their committed offsets as values.
 
+        When auto-commit is enabled, returns None since rdkafka handles
+        commits automatically and we don't track which offsets were committed.
+
         Raises an ``InvalidState`` if called on a closed consumer.
         """
-        return self.__commit_retry_policy.call(self.__commit)
+        if self.__use_auto_commit:
+            # When auto-commit is enabled, rdkafka commits automatically
+            # We don't track what was committed, so return None
+            # The offsets have already been staged via store_offsets()
+            return None
+        else:
+            return self.__commit_retry_policy.call(self.__commit)
 
     def close(self, timeout: Optional[float] = None) -> None:
         """
